import {defineConfig} from 'vitepress';
import {applyPlugins} from '@ruabick/md-demo-plugins';
import {genTemp} from '@ruabick/vite-plugin-gen-temp';
import {genApiDoc} from '@ruabick/vite-plugin-gen-api-doc';
import {sidebar} from './sidebar.js';
import {resolve} from 'path';

export default defineConfig({
    lang: 'zh-CN',
    lastUpdated: true,
    title: "hc-vue3-ui",
    themeConfig: {
        logo: '/favicon.ico',
        outlineTitle: '此页的大纲',
        nav: [
            {
                text: '使用说明',
                link: '/guide/index'
            },
            {
                text: '组件库',
                link: '/components/app-config/index'
            },
            {
                text: 'API函数',
                link: '/api/storage/index'
            },
            {
                text: '样式说明',
                link: '/style/base/index'
            },
            {
                text: '资料导航',
                link: '/guide/nav'
            },
            {
                text: '更新日志',
                link: '/CHANGELOG.md'
            },
        ],
        sidebar,
        search: {
            provider: 'local'
        }
    },
    vue: {},
    vite: {
        resolve: {
            alias: {
                'docs': resolve('./src/'),
            },
        },
        plugins: [
            genTemp(),
            genApiDoc(),
        ],
        server: {
            port: 3300,
        }
    },
    markdown: {
        config: (md) => {
            applyPlugins(md);
        },
        theme: {
            light: 'github-light',
            dark: 'github-dark',
        },
    },
    buildEnd() {
        process.exit(0);
    },
});
