---
map:
path: /api/request/index
---

# 发起请求

基于 `axios` 封装的请求


## Http请求

虽然有了封装，但没有对错误信息做一些处理，比如身份失效等，所以，建议再次封装一下，如下：

```javascript
// src/api/request/index.js
import { httpApi } from "hc-vue3-ui"

//主要请求的封装
export const HcApi = async (obj, msg = true) => {
    return new Promise((resolve) => {
        //发起请求
        httpApi(obj).then((response) => {
            resolve(response)
        }).catch((response) => {
            getResData(response, msg)
            resolve(response)
        })
    })
}

//处理数据
const getResData = ({ code, msg }, isMsg = false) => {
    if (code === 401) {
        window.$message?.error('身份失效,请重新登录！')
        //router.push({ path: '/login' })  //跳转到登录页
    } else if (code !== 404 && code !== 500 && code !== 504) {
        if (isMsg) window.$message?.error(msg)
    }
}
```

## 对接口的调用处理

```javascript
// src/api/modules/user.js
import { HcApi } from '../request/index'

// method 为 post，params 有参数时，此请求为url拼接参数的方式请求，如 /api/login?name=xxx
export const userLogin = (params = {}) => HcApi({
    url: '/api/login',
    method: 'post',
    headers: {
        'TenantId': 'xxxx',
    },
    params: params,
})

// method 为 post，data 有参数时，此请求为json格式请求
export const userLogin1 = (form = {}) => HcApi({
    url: '/api/login',
    method: 'post',
    headers: {
        'Tenant-Id': xxxx,
    },
    data: form,
})
```

## 页面功能处使用


```javascript
import { userLogin } from '../src/api/modules/user'

const testUserLogin = async () => {
    //请求会返回的参数
    let test = {
        val: '原始请求响应数据',
        res: '请求响应的数据',
        data: '后端处理后返回的数据位置',
        code: '后端处理后返回的状态码，以及请求响应的状态码',
        msg: '后端处理后返回的提示信息',
        disposition: '请求响应头中的 content-disposition 字段',
        headers: '请求响应头',
        error: '是否请求失败',
    }
    const { error, code,  msg } = await userLogin(formValue.value)
    //登录失败
    if (error && code !== 200) {
        window?.$message?.error(msg)
        return false
    }
    //登录成功
    //其它业务逻辑代码
}
```


## 请求头数据


```javascript
import { getHeader } from "hc-vue3-ui"
//通常用于上传组件中，需要携带上相关的身份信息头
console.log(getHeader())
```
