---
map:
path: /components/data-tree/index
---

# 全加载树

`HcDataTree` 基于 `element-plus` 的 `el-tree` 组件封装。

## 简单示例

<demo src="./demo/demo1.vue"></demo>

## 自定义节点示例

<demo src="./demo/demo2.vue"></demo>

## ref示例

<demo src="./demo/demo3.vue"></demo>

## props 参数

| 名称                 | 类型            | 默认值          | 可选值        | 说明                            |
|--------------------|---------------|--------------|------------|-------------------------------|
| ui                 | String        | -            | -          | 附加 class 类名                   |
| datas              | Array         | -            | -          | 节点数据                          |
| treeKey            | String/Number | primaryKeyId | -          | 每个树节点用来作为唯一标识的属性，整棵树应该是唯一的    |
| autoExpandKeys     | Array         | -            | -          | 自动展开的节点数组，注意排序，要从顶级开始         |
| menus              | Array         | -            | -          | 右键菜单数据，如果不传递，就没有右键菜单功能        |
| rootMenu           | Array         | -            | -          | 根节点的右键菜单数据，如果不传递，根节点就没有右键菜单功能 |
| isMark             | Boolean       | false        | true、false | 右键菜单数据，是否有标记菜单项               |
| isType             | Boolean       | false        | true、false | 是否显示类型标志                      |
| isCounts           | Boolean       | false        | true、false | 是否显示统计数量                      |
| hProps             | Object        | -            | -          | 树数据的格式                        |
| searchVal          | String        | -            | -          | 搜索的字符串                        |
| defaultCheckedKeys | Array         | -            | -          | 默认勾选的节点的 key 的数组              |
| defaultExpandAll   | Boolean       | false        | true、false | 是否默认展开所有节点                    |
| showCheckbox       | Boolean       | false        | true、false | 节点是否可被选择（复选框）                 |
| checkStrictly      | Boolean       | false        | true、false | 在显示复选框的情况下，是否严格的遵循父子不互相关联的做法  |


<div class="tip custom-block" style="padding-top: 8px">

`autoExpandKeys` 说明：示例格式 `['12345', '78910']`，键值对应 `treeKey` 的值

`menus` 说明：菜单数据，请参考 `右键菜单` 组件的参数

</div>

## hProps 参数

| 名称       | 类型     | 默认值      | 可选值 | 说明                     |
|----------|--------|----------|-----|------------------------|
| label    | String | title    | -   | 指定节点标签为节点对象的某个属性值      |
| children | String | children | -   | 指定子树为节点对象的某个属性值        |
| disabled | String | disabled | -   | 指定节点选择框是否禁用为节点对象的某个属性值 |


## slot 插槽

| 名称      | 说明                              |
|---------|---------------------------------|
| default | 默认插槽，携带数据 `{node, data, level}` |

<div class="tip custom-block" style="padding-top: 8px">

当使用插槽时，`isType`、`isCounts` 参数将失效

</div>


## emit 事件

| 名称           | 返回类型   | 返回数据                      | 说明           |
|--------------|--------|---------------------------|--------------|
| menuTap      | Object | `{key, node, data, keys}` | 右键菜单被点击事件    |
| nodeTap      | Object | `{node, data, keys}`      | 树节点被点击事件     |
| filter       | -      | -                         | 搜索筛选事件       |
| check        | -      | 见下文                       | 点击节点复选框之后触发  |
| check-change | -      | 见下文                       | 当复选框被点击的时候触发 |


<div class="tip custom-block" style="padding-top: 8px">

`keys` 说明：自动展开的节点key，已经排序好的，通常用来做缓存和赋值即可

`check` 说明：共两个参数，依次为：传递给 data 属性的数组中该节点所对应的对象、树目前的选中状态对象，包含 `checkedNodes`、`checkedKeys`、`halfCheckedNodes`、`halfCheckedKeys` 四个属性

`check-change` 说明：共三个参数，依次为：传递给 data 属性的数组中该节点所对应的对象、节点本身是否被选中、节点的子树中是否有被选中的节点

</div>


## 方法 参数

| 名称                               | 返回类型 | 返回数据 | 说明          |
|----------------------------------|------|------|-------------|
| setElTreeMenuMark(keys, isFirst) | -    | -    | 设置树菜单的标记数据  |
| removeElTreeNode(key)            | -    | -    | 删除树节点       |
| filterNode(value, data, node)    | -    | -    | 节点过滤        |
| getRef()                         | -    | -    | 获取树的原始ref   |
| treeRef                          | -    | -    | 树的ref (未测试) |
