---
map:
path: /components/upload-file/index
---

# 文件上传

支持分片上传的文件上传组件


## 简单示例

<demo src="./demo/demo1.vue"></demo>


## 先打开弹窗

<demo src="./demo/demo2.vue"></demo>


## 拖动上传

<demo src="./demo/demo3.vue"></demo>


## props 参数

| 名称         | 类型      | 默认值   | 可选值          | 说明                       |
|------------|---------|-------|--------------|--------------------------|
| ui         | String  | -     | -            | 附加 class 类名              |
| options    | Object  | -     | -            | 上传文件的配置                  |
| params     | Object  | -     | -            | 发送给服务器的额外参数              |
| echoParams | Object  | -     | -            | 回显参数，此参数不会提交服务器，只会在事件里返回 |
| drop       | Boolean | false | false / true | 是否为拖动上传                  |
| useFile    | Boolean | false | false / true | 是否显示使用文件功能               |

<div class="tip custom-block" style="padding-top: 8px">

`echoParams` 说明：由于是多个文件上传，可能上传后，不同的文件，要执行不同操作，为了区分文件的不同，所以，在此参数里处理。

</div>


## options 参数

| 名称         | 类型      | 默认值   | 可选值        | 说明                 |
|------------|---------|-------|------------|--------------------|
| url        | String  | 见下方说明 | -          | 自定义小文件上传的Url       |
| name       | String  | file  | -          | 自定义文件上传参数名         |
| headers    | Object  | -     | -          | 请求头，此值必须要传，否则会上传失败 |
| accept     | String  | 见下方说明 | -          | 自定义文件上传类型          |
| accept_tip | String  | 见下方说明 | -          | 自定义文件上传类型提示        |
| size       | Number  | 10    | -          | 开启分片的大小，单位是MB      |
| multiple   | Boolean | true  | true、false | 是否可多选文件            |


<div class="tip custom-block" style="padding-top: 8px">

`url` 默认值：/blade-resource/oss/endpoint/upload-file

`accept` 默认值：image/png,image/jpg,image/jpeg,application/vnd.openxmlformats-officedocument.spreadsheetml.sheet,application/vnd.ms-excel,application/pdf,.doc,.docx,application/msword

`accept_tip` 默认值：`图片(png、jpg、jpeg)<br/>Excel(xls、xlsx)<br/>PDF<br/>Word(doc、docx)`

`headers` 说明：此值必须要传，否则会上传失败

`size` 说明：开启分片的大小，单位是MB，低于此值的走小文件接口（也就是此配置项里的 `url` 参数接口），高于此值的走分片上传，分片为2MB

</div>


## slot 插槽

| 名称      | 说明   |
|---------|------|
| default | 默认插槽 |


## emit 事件

| 名称       | 返回类型   | 返回数据             | 说明                    |
|----------|--------|------------------|-----------------------|
| progress | Object | `{file, status}` | 文件上传中，此事件是单个文件上传中时会触发 |
| success  | Object | fileData 对象      | 文件上传成功，返回一个当前文件的数据对象  |
| error    | Object | fileData 对象      | 文件上传失败 ，返回一个当前文件的数据对象 |
| pause    | Object | `{item, index}`  | 文件暂停上传                |
| resume   | Object | `{item, index}`  | 文件继续上传                |
| retry    | Object | `{item, index}`  | 重新上传文件                |
| cancel   | Object | `{item, index}`  | 取消上传并从列表中移除           |
| item     | Object | `{item, index}`  | 点击了使用此文件的事件           |
| finish   | Array  | 文件列表数据           | 全部文件上传完成              |


<div class="tip custom-block" style="padding-top: 8px">

`{item, index}` 说明：item 是当前文件的数据对象，index 是当前文件在列表中的索引

`finish` 说明：如果操作了最后一个上传文件的取消、移除、暂停等，不会触发此事件，保留用户的继续操作意图，如果没有操作，正常全部上传完成（包括上传失败的）后，会触发此事件

</div>


## 方法 参数

| 名称                    | 返回类型    | 返回数据                                         | 说明                    |
|-----------------------|---------|----------------------------------------------|-----------------------|
| selectFile()          | -       | -                                            | 触发选择文件进行上传的操作         |
| setModalShow(Boolean) | -       | -                                            | 是否显示文件列表弹框，true、false |
| getFileList()         | Object  | `{totalFileList, uploading, success, error}` | 获取文件列表                |
| allPause()            | -       | -                                            | 全部上传暂停                |
| allUpload()           | -       | -                                            | 全部继续上传                |
| allCancel()           | -       | -                                            | 取消并移除所有文件，包括已上传文件     |
| getIsUploading()      | Boolean | true、false                                   | 是否还有正在上传中的文件          |
| cancelUpload()        | -       | -                                            | 清空所有文件                |


<div class="tip custom-block" style="padding-top: 8px">

`{totalFileList, uploading, success, error}` 说明：

`totalFileList` ： 所有文件列表

`uploading` ： 正在上传中的列表

`success` ： 已上传完成的列表

`error` ： 上传失败的列表

</div>
