---
map:
path: /style/base/index
---

# 基础说明

由于为了减轻项目中使用时的打包体积，移除了很多样式，所以，在项目中使用时，需要引入或安装以下这些库或样式


`tailwindcss` [样式处理库](https://tailwindcss.com/docs/container) ，`remixicon` [字体图标库](https://remixicon.cn/)

`import 'element-plus/dist/index.css'` [element-plus组件库的样式](https://element-plus.org/zh-CN/guide/quickstart.html#%E5%AE%8C%E6%95%B4%E5%BC%95%E5%85%A5)


为了减轻打包体积，不建议直接安装或引入这些样式，否则可能会导致打包后的某个css文件会巨大，导致首次加载巨慢


推荐将  `remixicon` 、 `element-plus` 库的编译版本，放入项目的 `public` 目录下，然后，在 `index.html` 中加载样式文件，这样，就不会将这些文件编译打包了

``` html
<!DOCTYPE html>
<html lang="zh">
    <head>
        <meta charset="UTF-8"/>
        <link rel="icon" href="/favicon.ico"/>
        <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
        <!--参考此处-->
        <link rel="stylesheet" href="/plugins/element-plus-v2.3.6/index.css"/>
        <link rel="stylesheet" href="/plugins/element-plus-v2.3.6/theme-chalk/dark/css-vars.css"/>
        <link rel="stylesheet" href="/plugins/remixicon-v3.3.0/remixicon.css"/>
        <link rel="stylesheet" href="/plugins/fonts/index.css"/>
        <!--完结-->
        <title></title>
    </head>
    <body>
        <div id="app"></div>
        <script type="module" src="/src/main.js"></script>
    </body>
</html>
```

具体详情，请参考 [for_client](http://47.110.251.215:3000/web/for_client) 项目的结构


## 目录结构

`style` 的 目录结构

```
style (全局样式)
│  ├─ app (文件夹)
│  │  ├─ _color.scss (颜色生成，背景色、文本色等)
│  │  ├─ _main.scss (主全局样式)
│  │  ├─ _text.scss (文本样式，字体大小之类的)
│  │  ├─ _var.scss (全局变量)
│  │  ├─ element.scss (element-plus组件库的样式覆盖)
│  │  ├─ theme.scss (主题样式)
│  │  ├─ tools.scss (scss函数)
│  │  └─ tree.scss (树的样式)
│  ├─ index.scss (全部引用)
└─ └─ tailwind.scss （tailwindcss的样式）
```

## 样式引用

js的引用方式

``` javascript
//全局样式
import 'hc-vue3-ui/style/index.scss'

//全局变量
import 'hc-vue3-ui/style/app/_var.scss'
```

scss 的引用方式

``` scss
//全局样式
@import 'hc-vue3-ui/style/index.scss';

//全局变量
@import 'hc-vue3-ui/style/app/_var.scss';
```
